CreatedOutput

Struct CreatedOutput 

pub struct CreatedOutput { /* private fields */ }
Represents a newly created output.

Implementations

Source

impl CreatedOutput

pub fn new( block_id: BlockId, milestone_index: MilestoneIndex, milestone_timestamp: u32, inner: Output, ) -> Self

Creates a new CreatedOutput.

pub fn block_id(&self) -> &BlockId

Returns the block id of the CreatedOutput.

pub fn milestone_index(&self) -> MilestoneIndex

Returns the milestone index of the CreatedOutput.

pub fn milestone_timestamp(&self) -> u32

Returns the milestone milestone timestamp of the CreatedOutput.

pub fn inner(&self) -> &Output

Returns the inner output of the CreatedOutput.

Methods from Deref<Target = Output>

pub const AMOUNT_MIN: u64 = 1

pub fn kind(&self) -> u8

Return the output kind of an Output.

pub fn amount(&self) -> u64

Returns the amount of an Output.

pub fn native_tokens(&self) -> Option<&NativeTokens>

Returns the native tokens of an Output, if any.

pub fn unlock_conditions(&self) -> Option<&UnlockConditions>

Returns the unlock conditions of an Output, if any.

pub fn features(&self) -> Option<&Features>

Returns the features of an Output, if any.

pub fn immutable_features(&self) -> Option<&Features>

Returns the immutable features of an Output, if any.

pub fn chain_id(&self) -> Option<ChainId>

Returns the chain identifier of an Output, if any.

pub fn verify_storage_deposit( &self, rent_structure: RentStructure, token_supply: u64, ) -> Result<(), Error>

Verifies if a valid storage deposit was made. Each Output has to have an amount that covers its associated byte cost, given by RentStructure. If there is a StorageDepositReturnUnlockCondition, its amount is also checked.