pub struct TreasuryDiff { /* private fields */ }Expand description
Wraps together the identifiers of the milestones that created and consumed treasury outputs.
Implementations
Sourceimpl TreasuryDiff
impl TreasuryDiff
Sourcepub fn new(created: MilestoneId, consumed: MilestoneId) -> Self
pub fn new(created: MilestoneId, consumed: MilestoneId) -> Self
Creates a new TreasuryDiff.
Sourcepub fn created(&self) -> &MilestoneId
pub fn created(&self) -> &MilestoneId
Returns the id of the milestone that created the treasury output associated to the TreasuryDiff.
Sourcepub fn consumed(&self) -> &MilestoneId
pub fn consumed(&self) -> &MilestoneId
Returns the id of the milestone that consumed the treasury input associated to the TreasuryDiff.