pub struct CreatedOutput { /* private fields */ }Expand description
Represents a newly created output.
Implementations
Sourceimpl CreatedOutput
impl CreatedOutput
Sourcepub fn new(
block_id: BlockId,
milestone_index: MilestoneIndex,
milestone_timestamp: u32,
inner: Output,
) -> Self
pub fn new( block_id: BlockId, milestone_index: MilestoneIndex, milestone_timestamp: u32, inner: Output, ) -> Self
Creates a new CreatedOutput.
Sourcepub fn block_id(&self) -> &BlockId
pub fn block_id(&self) -> &BlockId
Returns the block id of the CreatedOutput.
Sourcepub fn milestone_index(&self) -> MilestoneIndex
pub fn milestone_index(&self) -> MilestoneIndex
Returns the milestone index of the CreatedOutput.
Sourcepub fn milestone_timestamp(&self) -> u32
pub fn milestone_timestamp(&self) -> u32
Returns the milestone milestone timestamp of the CreatedOutput.
Sourcepub fn inner(&self) -> &Output
pub fn inner(&self) -> &Output
Returns the inner output of the CreatedOutput.
Methods from Deref<Target = Output>
pub const AMOUNT_MIN: u64 = 1
Sourcepub fn native_tokens(&self) -> Option<&NativeTokens>
pub fn native_tokens(&self) -> Option<&NativeTokens>
Returns the native tokens of an Output, if any.
Sourcepub fn unlock_conditions(&self) -> Option<&UnlockConditions>
pub fn unlock_conditions(&self) -> Option<&UnlockConditions>
Returns the unlock conditions of an Output, if any.
Sourcepub fn immutable_features(&self) -> Option<&Features>
pub fn immutable_features(&self) -> Option<&Features>
Returns the immutable features of an Output, if any.
Sourcepub fn verify_storage_deposit(
&self,
rent_structure: RentStructure,
token_supply: u64,
) -> Result<(), Error>
pub fn verify_storage_deposit( &self, rent_structure: RentStructure, token_supply: u64, ) -> Result<(), Error>
Verifies if a valid storage deposit was made. Each Output has to have an amount that covers its associated
byte cost, given by RentStructure.
If there is a StorageDepositReturnUnlockCondition,
its amount is also checked.